==> ugene_1.3.3+repack.orig.tar.gz: ugene-1.3.3/src/core/src/util_ov_annotated_dna/DetView.h <==
/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _GB2_DET_VIEW_H_
#define _GB2_DET_VIEW_H_

#include "GSequenceLineViewAnnotated.h"

#include <QtGui/QFont>
#include <QtGui/QAction>

class QActionGroup;

namespace GB2 {

class DNATranslation;

class GB2_COREAPI_EXPORT DetView : public GSequenceLineViewAnnotated {
	Q_OBJECT

public:
	DetView(QWidget* p, ADVSequenceObjectContext* ctx);

	bool isOneLineMode()  {return getComplementTT() == NULL && getAminoTT() == NULL;}
	bool hasTranslations()  {return getAminoTT() != NULL;}
	bool hasComplementStrand()  {return getComplementTT() != NULL;}
    
    DNATranslation* getComplementTT() const;
    DNATranslation* getAminoTT() const;

    void setShowComplement(bool t);
    void setShowTranslation(bool t);

    QAction* getShowComplementAction() const {return showComplementAction;}
    QAction* getShowTranslationAction() const {return showTranslationAction;}

protected slots:
    void sl_onAminoTTChanged();
    void sl_showComplementToggle(bool v) {setShowComplement(v);}
    void sl_showTranslationToggle(bool v) {setShowTranslation(v);}

protected:
    void showEvent(QShowEvent * e);
    void hideEvent(QHideEvent * e);

    void updateActions();

	void resizeEvent(QResizeEvent *e);
    void updateSize();

    QAction*        showComplementAction;
    QAction*        showTranslationAction;
};


class DetViewRenderArea : public GSequenceLineViewAnnotatedRenderArea {
public:
	DetViewRenderArea(DetView* d);
	
	virtual int coordToPos(int x) const;
	virtual float posToCoordF(int x, bool useVirtualSpace = false) const;
	virtual float getCurrentScale() const; 

	int getCharWidth() const {return charWidth;}
	DetView*		getDetView() const {return (DetView*)view;}

	virtual LRegion getAnnotationYRange(Annotation* a, const LRegion& r, const AnnotationSettings* as) const;
    
    void updateSize();

protected:
	virtual void drawAll(QPaintDevice* pd);


private:
	int getLineY(int line) const {return 2 + line * lineHeight;}
	int getTextY(int line) const {return getLineY(line) + lineHeight - yCharOffset;}

	void updateFontMetrics();
	void updateLines();
	void drawDirect(QPainter& p);
	void drawComplement(QPainter& p);
	void drawTranslations(QPainter& p);
	void drawSequenceSelection(QPainter& p);
	void drawRuler(QPainter& p);
	void highlight(QPainter& p, const LRegion& r, int line);
	
	int posToComplTransLine(int p) const;
	int posToDirectTransLine(int p) const;

	int				numLines;
	int				rulerLine;
	int				baseLine;
	int				complementLine;
	int				firstDirectTransLine;
	int				firstComplTransLine;
	int				charWidth;
	int				lineHeight;
	int				yCharOffset;
	int				xCharOffset;
	QFont			font;
	QFont			rulerFont;
};


}//namespace;

#endif

==> ugene_1.5.2+repack.orig.tar.gz: ugene-1.5.2/src/core/src/util_ov_annotated_dna/DetView.h <==
/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _GB2_DET_VIEW_H_
#define _GB2_DET_VIEW_H_

#include "GSequenceLineViewAnnotated.h"

#include <QtGui/QFont>
#include <QtGui/QAction>

class QActionGroup;

namespace GB2 {

class DNATranslation;

class GB2_COREAPI_EXPORT DetView : public GSequenceLineViewAnnotated {
	Q_OBJECT

public:
	DetView(QWidget* p, ADVSequenceObjectContext* ctx);

	bool isOneLineMode()  {return getComplementTT() == NULL && getAminoTT() == NULL;}
	bool hasTranslations()  {return getAminoTT() != NULL;}
	bool hasComplementStrand()  {return getComplementTT() != NULL;}
    
    DNATranslation* getComplementTT() const;
    DNATranslation* getAminoTT() const;

    void setShowComplement(bool t);
    void setShowTranslation(bool t);

    QAction* getShowComplementAction() const {return showComplementAction;}
    QAction* getShowTranslationAction() const {return showTranslationAction;}

protected slots:
    virtual void sl_sequenceChanged();
    void sl_onAminoTTChanged();
    void sl_showComplementToggle(bool v) {setShowComplement(v);}
    void sl_showTranslationToggle(bool v) {setShowTranslation(v);}

protected:
    void showEvent(QShowEvent * e);
    void hideEvent(QHideEvent * e);
    
    void mouseReleaseEvent(QMouseEvent* me);

    void updateActions();

	void resizeEvent(QResizeEvent *e);
    void updateSize();

    QAction*        showComplementAction;
    QAction*        showTranslationAction;
};


class DetViewRenderArea : public GSequenceLineViewAnnotatedRenderArea {
public:
	DetViewRenderArea(DetView* d);
	
	virtual int coordToPos(int x) const;
	virtual float posToCoordF(int x, bool useVirtualSpace = false) const;
	virtual float getCurrentScale() const; 

	DetView*		getDetView() const {return (DetView*)view;}

	virtual LRegion getAnnotationYRange(Annotation* a, const LRegion& r, const AnnotationSettings* as) const;
    
    void updateSize();

    bool isOnTranslationsLine(int y) const;

protected:
	virtual void drawAll(QPaintDevice* pd);


private:
	int getLineY(int line) const {return 2 + line * lineHeight;}
	int getTextY(int line) const {return getLineY(line) + lineHeight - yCharOffset;}

	void updateLines();
	void drawDirect(QPainter& p);
	void drawComplement(QPainter& p);
	void drawTranslations(QPainter& p);
	void drawSequenceSelection(QPainter& p);
	void drawRuler(QPainter& p);
	void highlight(QPainter& p, const LRegion& r, int line);
	
	int posToComplTransLine(int p) const;
	int posToDirectTransLine(int p) const;

	int				numLines;
	int				rulerLine;
	int				baseLine;
	int				complementLine;
	int				firstDirectTransLine;
	int				firstComplTransLine;
};


}//namespace;

#endif
